@@ -1,4 +1,5 @@
-#include <stdbool.h>
+
+#include <R_ext/Boolean.h>
 #include <math.h>
 #include "utils.h"
 
@@ -8,9 +9,9 @@ void CCubes(
     const int nconds,       // number of conditions in the data
     const double p_data[],  // calibrated dataset
     const int nrdata,       // number of rows in the raw data
-    const bool allsol,      // all solution
-    const bool rowdom,      // row dominance
-    const bool minpin,      // minimal number of PIs
+    const Rboolean allsol,      // all solution
+    const Rboolean rowdom,      // row dominance
+    const Rboolean minpin,      // minimal number of PIs
     const double picons,    // PI consistency
     const int pidepth,      // depth in number of conditions for each PI
     const int p_fsconds[],  // are conditions fuzzy?
@@ -18,17 +19,17 @@ void CCubes(
     const double solcons,
     const double solcov,
     const double maxcomb,
-    const bool keeptrying,
+    const Rboolean keeptrying,
 
     // pointers to save the results
     int **pichart,          // final PI chart
     int **implicants,       // final implicants in matrix form
     int **models,           // final solution models
-    int *foundPI_,          // final number of PIs found
+    unsigned int *foundPI_, // final number of PIs found
     int *solrows,           // number of rows for the solution matrix
     int *solcols,           // number of columns for the solution matrix
-    bool *complex,          // signal if the returned solution is incomplete due to a too complex PI chart
-    // int *solmin_,           // solution minima
+    Rboolean *complex,          // signal if the returned solution is incomplete due to a too complex PI chart
+    // int *solmin_,        // solution minima
 
-    const bool firstmin
+    const Rboolean firstmin
 );
